@@ -3,11 +3,12 @@
 
 package Mediawiki::POD::HTML;
 
+use 5.008001;
 use base qw/Pod::Simple::HTML/;
 use Graph::Easy;
 use Graph::Easy::Parser;
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 use strict;
 
@@ -29,6 +30,8 @@ sub new
   $storage->{headlines} = [];
   $storage->{graph_id} = 0;
 
+  $storage->{search} = 'http://cpan.uwinnipeg.ca/search?query=##KEYWORD##';
+
   # we handle these, too:
   $self->accept_targets('graph', 'GRAPH');
 
@@ -42,6 +45,8 @@ sub _handle_element_start
   {
   my ($self, $element_name, $attr) = @_;
 
+  #print STDERR "start '$element_name'\n";
+
   my $storage = $self->{_mediawiki_pod_html};
 
   if ($element_name eq 'X' && $storage->{in_x} == 0)
@@ -56,6 +61,20 @@ sub _handle_element_start
     $storage->{in_x} = 0;
     }
 
+  if ($storage->{in_graph} && $element_name !~ /^Data/i)
+    {
+    my $parser = Graph::Easy::Parser->new();
+
+    my $graph = $parser->from_text($storage->{cur_graph});
+    
+    $graph->set_attribute('gid', $storage->{graph_id}++);
+
+    $self->_my_output( '<style type="text/css">' . $graph->css() . '</style>' );
+    $self->_my_output( $graph->as_html() );
+
+    $storage->{in_graph} = 0;
+    $storage->{cur_graph} = '';
+    }
   # other items
   if ($element_name eq 'for' && ($attr->{target} || '') eq 'graph')
     {
@@ -63,10 +82,6 @@ sub _handle_element_start
     $storage->{cur_graph} = '';
     return;
     }
-  if ($element_name !~ /^Data/i)
-    {
-    $storage->{in_graph} = 0;
-    }
 
   if ($element_name =~ /^head/)
     {
@@ -81,27 +96,14 @@ sub _handle_element_end
   {
   my ($self, $element_name) = @_;
 
+  #print STDERR "end '$element_name'\n";
+
   my $storage = $self->{_mediawiki_pod_html};
 
   if ($element_name =~ /^head/)
     {
     $storage->{in_headline} = 0;
     }
-  if ($element_name =~ /Data/i && $storage->{in_graph})
-    {
-    my $parser = Graph::Easy::Parser->new();
-
-    my $graph = $parser->from_text($storage->{cur_graph});
-    
-    $graph->set_attribute('gid', $storage->{graph_id}++);
-
-    $self->_my_output( '<style type="text/css">' . $graph->css() . '</style>' );
-    $self->_my_output( $graph->as_html() );
-
-    $storage->{in_graph} = 0;
-    $storage->{cur_graph} = '';
-    return;
-    }
 
   $self->SUPER::_handle_element_end($element_name);
   }
@@ -109,6 +111,8 @@ sub _handle_element_end
 sub _handle_text {
   my ($self, $text) = @_;
 
+  #print STDERR "text '$text'\n";
+
   my $storage = $self->{_mediawiki_pod_html};
   if ($storage->{in_headline})
     {
@@ -121,7 +125,19 @@ sub _handle_text {
     }
   if ($storage->{in_x})
     {
-    $self->_my_output( "<span class='keyword'>$text</span>" );
+    my $url = $storage->{search};
+    my $t = $text;
+    $t =~ s/&/&mp;/;
+    $t =~ s/'/&squot;/;
+    if ($url =~ /##KEYWORD##/)
+      {
+      $url =~ s/##KEYWORD##/$t/g;
+      }
+    else
+      {
+      $url .= $t;
+      }
+    $self->_my_output( "<a class='keyword' href='$url'>$text</a>" );
     return;
     }
 
@@ -136,6 +152,15 @@ sub get_headlines
   $storage->{headlines};
   }
 
+sub keyword_search_url
+  {
+  my $self = shift;
+
+  my $storage = $self->{_mediawiki_pod_html};
+  $storage->{search} = $_[0] if defined $_[0];
+  $storage->{search};
+  }
+
 sub _my_output
   {
   my $self = shift;
@@ -175,6 +200,26 @@ the captured headlines.
 
 Return all the captured headlines as an ARRAY ref.
 
+=head2 keyword_search_url()
+
+Get/set the URL that is used to link keywords defined with C<< X&lt;&gt; >>
+to a search engine. 
+
+If the URL contains a text C<##KEYWORD##>, then this text will be replaced
+with the actual keyword. Otherwise, the keyword is simple appended to the URL.
+
+The default search URL is:
+
+  	http://cpan.uwinnipeg.ca/search?query=##KEYWORD##
+
+Examples:
+
+	# External search engine
+	$parser->keyword_search_url('http://search.cpan.org/perldoc?');
+
+	# will generate URLs like "example", perfect for relative links
+	$parser->keyword_search_url('');
+
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify
